import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

var __rest = this && this.__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

import { CloseOutlined } from "msb-icons-svg/es/src";
import classNames from 'classnames';
import RcDrawer from 'rc-drawer';
import * as React from 'react';
import { ConfigContext } from '../config-provider';
import { NoFormStyle } from '../form/context';
import { getTransitionName } from '../_util/motion';
import { tuple } from '../_util/type';
import warning from '../_util/warning';
var SizeTypes = tuple('small', 'medium', 'large', 'extra-large'); // msb overwrite start

var sizeSmall = '40%';
var sizeMedium = '60%';
var sizeLarge = '80%';
var sizeExtraLarge = '100%';

var mergedSize = function mergedSize(size) {
  switch (size) {
    case 'small':
      {
        return sizeSmall;
      }

    case 'medium':
      {
        return sizeMedium;
      }

    case 'large':
      {
        return sizeLarge;
      }

    case 'extra-large':
      {
        return sizeExtraLarge;
      }

    default:
      {
        return sizeSmall;
      }
  }
};

var defaultPushState = {
  distance: 180
};

function BottomSheet(props) {
  var height = props.height,
      _props$size = props.size,
      size = _props$size === void 0 ? 'small' : _props$size,
      _props$closable = props.closable,
      closable = _props$closable === void 0 ? true : _props$closable,
      _props$mask = props.mask,
      mask = _props$mask === void 0 ? true : _props$mask,
      _props$push = props.push,
      push = _props$push === void 0 ? defaultPushState : _props$push,
      _props$closeIcon = props.closeIcon,
      closeIcon = _props$closeIcon === void 0 ? /*#__PURE__*/React.createElement(CloseOutlined, null) : _props$closeIcon,
      bodyStyle = props.bodyStyle,
      drawerStyle = props.drawerStyle,
      className = props.className,
      visible = props.visible,
      open = props.open,
      children = props.children,
      style = props.style,
      title = props.title,
      headerStyle = props.headerStyle,
      onClose = props.onClose,
      footer = props.footer,
      footerStyle = props.footerStyle,
      customizePrefixCls = props.prefixCls,
      customizeGetContainer = props.getContainer,
      iconLeft = props.iconLeft,
      afterVisibleChange = props.afterVisibleChange,
      _afterOpenChange = props.afterOpenChange,
      rest = __rest(props, ["height", "size", "closable", "mask", "push", "closeIcon", "bodyStyle", "drawerStyle", "className", "visible", "open", "children", "style", "title", "headerStyle", "onClose", "footer", "footerStyle", "prefixCls", "getContainer", "iconLeft", "afterVisibleChange", "afterOpenChange"]);

  var _React$useContext = React.useContext(ConfigContext),
      getPopupContainer = _React$useContext.getPopupContainer,
      getPrefixCls = _React$useContext.getPrefixCls,
      direction = _React$useContext.direction;

  var prefixCls = getPrefixCls('bottom-sheet', customizePrefixCls);
  var getContainer = // 有可能为 false，所以不能直接判断
  customizeGetContainer === undefined && getPopupContainer ? function () {
    return getPopupContainer(document.body);
  } : customizeGetContainer;
  var closeIconNode = closable && /*#__PURE__*/React.createElement("button", {
    type: "button",
    onClick: onClose,
    "aria-label": "Close",
    className: "".concat(prefixCls, "-close")
  }, closeIcon);
  [['visible', 'open'], ['afterVisibleChange', 'afterOpenChange']].forEach(function (_ref) {
    var _ref2 = _slicedToArray(_ref, 2),
        deprecatedName = _ref2[0],
        newName = _ref2[1];

    process.env.NODE_ENV !== "production" ? warning(!(deprecatedName in props), 'Drawer', "`".concat(deprecatedName, "` is deprecated which will be removed in next major version, please use `").concat(newName, "` instead.")) : void 0;
  });

  function renderHeader() {
    if (!title && !closable) {
      return null;
    }

    return /*#__PURE__*/React.createElement("div", {
      className: classNames("".concat(prefixCls, "-header"), _defineProperty({}, "".concat(prefixCls, "-header-close-only"), closable && !title && !iconLeft)),
      style: headerStyle
    }, iconLeft && /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-icon-left")
    }, iconLeft), /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-header-title")
    }, title && /*#__PURE__*/React.createElement("div", {
      className: "".concat(prefixCls, "-title")
    }, title)), closeIconNode);
  }

  function renderFooter() {
    if (!footer) {
      return null;
    }

    var footerClassName = "".concat(prefixCls, "-footer");
    return /*#__PURE__*/React.createElement("div", {
      className: footerClassName,
      style: footerStyle
    }, footer);
  }

  var drawerClassName = classNames(_defineProperty({
    'no-mask': !mask
  }, "".concat(prefixCls, "-rtl"), direction === 'rtl'), className); // ============================ Size ============================
  // msb overwrite start

  var mergedHeight = React.useMemo(function () {
    return height !== null && height !== void 0 ? height : mergedSize(size);
  }, [height, size]); // msb overwrite end
  // =========================== Motion ===========================

  var maskMotion = {
    motionName: getTransitionName(prefixCls, 'mask-motion'),
    motionAppear: true,
    motionEnter: true,
    motionLeave: true,
    motionDeadline: 500
  };

  var panelMotion = function panelMotion(motionPlacement) {
    return {
      motionName: getTransitionName(prefixCls, "panel-motion-".concat(motionPlacement)),
      motionAppear: true,
      motionEnter: true,
      motionLeave: true,
      motionDeadline: 500
    };
  }; // =========================== Render ===========================


  return /*#__PURE__*/React.createElement(NoFormStyle, {
    status: true,
    override: true
  }, /*#__PURE__*/React.createElement(RcDrawer, _extends({
    prefixCls: prefixCls,
    onClose: onClose
  }, rest, {
    open: open || visible,
    mask: mask,
    push: push,
    height: mergedHeight,
    rootClassName: drawerClassName,
    getContainer: getContainer,
    afterOpenChange: function afterOpenChange(isOpen) {
      _afterOpenChange === null || _afterOpenChange === void 0 ? void 0 : _afterOpenChange(isOpen);
      afterVisibleChange === null || afterVisibleChange === void 0 ? void 0 : afterVisibleChange(isOpen);
    },
    maskMotion: maskMotion,
    motion: panelMotion,
    rootStyle: style,
    placement: "bottom"
  }), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-wrapper-body"),
    style: _extends({}, drawerStyle)
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-indicator")
  }), renderHeader(), /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-body"),
    style: bodyStyle
  }, children), renderFooter())));
}

if (process.env.NODE_ENV !== 'production') {
  BottomSheet.displayName = 'MenuList';
}

export default BottomSheet;