import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import classNames from 'classnames';
import * as React from 'react';
import ConfigProvider from '../config-provider';
import { Col, Row } from '../grid';
import ActionButton from '../_util/ActionButton';
import { getTransitionName } from '../_util/motion';
import warning from '../_util/warning';
import Dialog from './Modal';

var ConfirmDialog = function ConfirmDialog(props) {
  var icon = props.icon,
      onCancel = props.onCancel,
      onOk = props.onOk,
      close = props.close,
      zIndex = props.zIndex,
      afterClose = props.afterClose,
      visible = props.visible,
      open = props.open,
      keyboard = props.keyboard,
      centered = props.centered,
      getContainer = props.getContainer,
      maskStyle = props.maskStyle,
      okText = props.okText,
      _props$okButtonProps = props.okButtonProps,
      okButtonProps = _props$okButtonProps === void 0 ? {
    size: 'large'
  } : _props$okButtonProps,
      cancelText = props.cancelText,
      _props$cancelButtonPr = props.cancelButtonProps,
      cancelButtonProps = _props$cancelButtonPr === void 0 ? {
    size: 'large',
    type: 'primary'
  } : _props$cancelButtonPr,
      direction = props.direction,
      prefixCls = props.prefixCls,
      wrapClassName = props.wrapClassName,
      rootPrefixCls = props.rootPrefixCls,
      iconPrefixCls = props.iconPrefixCls,
      bodyStyle = props.bodyStyle,
      _props$closable = props.closable,
      closable = _props$closable === void 0 ? false : _props$closable,
      closeIcon = props.closeIcon,
      modalRender = props.modalRender,
      focusTriggerAfterClose = props.focusTriggerAfterClose,
      _props$footerButtonAl = props.footerButtonAlign,
      footerButtonAlign = _props$footerButtonAl === void 0 ? 'horizontal' : _props$footerButtonAl,
      buttonAddition = props.buttonAddition,
      _props$cancelType = props.cancelType,
      cancelType = _props$cancelType === void 0 ? 'ghost' : _props$cancelType,
      _props$btnBlock = props.btnBlock,
      btnBlock = _props$btnBlock === void 0 ? true : _props$btnBlock;
  process.env.NODE_ENV !== "production" ? warning(!(typeof icon === 'string' && icon.length > 2), 'Modal', "`icon` is using ReactNode instead of string naming in v4. Please check `".concat(icon, "` at https://ant.design/components/icon")) : void 0; // 支持传入{ icon: null }来隐藏`Modal.confirm`默认的Icon

  var okType = props.okType || 'primary';
  var contentPrefixCls = "".concat(prefixCls, "-confirm"); // 默认为 true，保持向下兼容

  var okCancel = 'okCancel' in props ? props.okCancel : true;
  var width = props.width || 485;
  var style = props.style || {};
  var mask = props.mask === undefined ? true : props.mask; // 默认为 false，保持旧版默认行为

  var maskClosable = props.maskClosable === undefined ? false : props.maskClosable;
  var autoFocusButton = props.autoFocusButton === null ? false : props.autoFocusButton || 'ok';
  var btnSpan = // eslint-disable-next-line no-nested-ternary
  btnBlock && footerButtonAlign === 'horizontal' ? 12 : footerButtonAlign === 'vertical' ? 24 : undefined;
  var classString = classNames(contentPrefixCls, "".concat(contentPrefixCls, "-").concat(props.type), _defineProperty({}, "".concat(contentPrefixCls, "-rtl"), direction === 'rtl'), props.className);
  var cancelButton = okCancel && /*#__PURE__*/React.createElement(Col, {
    span: btnSpan
  }, /*#__PURE__*/React.createElement(ActionButton, {
    type: cancelType,
    actionFn: onCancel,
    close: close,
    autoFocus: autoFocusButton === 'cancel',
    buttonProps: _extends({}, cancelButtonProps),
    prefixCls: "".concat(rootPrefixCls, "-btn")
  }, cancelText));
  var additionButton = footerButtonAlign === 'vertical' && buttonAddition && /*#__PURE__*/React.createElement(React.Fragment, null, buttonAddition.map(function (btnAdd, indexBtnAdd) {
    return (
      /*#__PURE__*/
      // eslint-disable-next-line react/no-array-index-key
      React.createElement(Col, {
        span: btnSpan,
        key: "confirm-btn-addition-".concat(indexBtnAdd)
      }, btnAdd)
    );
  }));
  return /*#__PURE__*/React.createElement(ConfigProvider, {
    prefixCls: rootPrefixCls,
    iconPrefixCls: iconPrefixCls,
    direction: direction
  }, /*#__PURE__*/React.createElement(Dialog, {
    prefixCls: prefixCls,
    className: classString,
    wrapClassName: classNames(_defineProperty({}, "".concat(contentPrefixCls, "-centered"), !!props.centered), wrapClassName),
    onCancel: function onCancel() {
      return close === null || close === void 0 ? void 0 : close({
        triggerCancel: true
      });
    },
    open: open || visible,
    title: "",
    footer: "",
    transitionName: getTransitionName(rootPrefixCls, 'zoom', props.transitionName),
    maskTransitionName: getTransitionName(rootPrefixCls, 'fade', props.maskTransitionName),
    mask: mask,
    maskClosable: maskClosable,
    maskStyle: maskStyle,
    style: style,
    bodyStyle: bodyStyle,
    width: width,
    zIndex: zIndex,
    afterClose: afterClose,
    keyboard: keyboard,
    centered: centered,
    getContainer: getContainer,
    closable: closable,
    closeIcon: closeIcon,
    modalRender: modalRender,
    focusTriggerAfterClose: focusTriggerAfterClose
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(contentPrefixCls, "-body-wrapper")
  }, /*#__PURE__*/React.createElement("div", {
    className: "".concat(contentPrefixCls, "-body")
  }, icon ? /*#__PURE__*/React.createElement("div", {
    className: "".concat(contentPrefixCls, "-body-icon space-mb-28")
  }, icon) : '', /*#__PURE__*/React.createElement("div", {
    className: "".concat(contentPrefixCls, "-body-title ")
  }, props.title === undefined ? null : /*#__PURE__*/React.createElement("span", {
    className: "".concat(contentPrefixCls, "-title")
  }, props.title)), /*#__PURE__*/React.createElement("div", {
    className: "".concat(contentPrefixCls, "-content space-mt-8")
  }, props.content)), /*#__PURE__*/React.createElement("div", {
    className: "".concat(contentPrefixCls, "-btns ").concat(contentPrefixCls, "-btns-").concat(footerButtonAlign)
  }, /*#__PURE__*/React.createElement(Row, {
    gutter: [16, 16],
    justify: btnBlock ? 'center' : 'end',
    reverse: footerButtonAlign === 'vertical' ? 'column' : undefined
  }, additionButton, cancelButton, /*#__PURE__*/React.createElement(Col, {
    span: btnSpan
  }, /*#__PURE__*/React.createElement(ActionButton, {
    type: okType,
    actionFn: onOk,
    close: close,
    autoFocus: autoFocusButton === 'ok',
    buttonProps: okButtonProps,
    prefixCls: "".concat(rootPrefixCls, "-btn")
  }, okText)))))));
};

export default ConfirmDialog;