import _extends from "@babel/runtime/helpers/esm/extends";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import React, { useCallback, useEffect, useImperativeHandle, useRef, useState } from 'react';
import ReactOtpInput from 'react-otp-input-rc-17';
import classNames from 'classnames';
import Button from '../button';
import Countdown from '../statistic/Countdown';
import Typography from '../typography';
import { DEFAULT_COUNT_DOWN_TIME, EXPIRED_OTP, NUMBER_OF_OTP_INPUT, RE_SEND_TEXT, TITLE_TEXT } from './interface';
import { getOtpCountTime, isBlockingTime, resetOtpCountTime, setOtpCountBlockTime, setOtpCountTime } from './utilities';
import { ConfigContext } from '../config-provider';
import Modal from '../modal';

var OtpComponent = function OtpComponent(props, ref) {
  var _props$titleText = props.titleText,
      titleText = _props$titleText === void 0 ? TITLE_TEXT : _props$titleText,
      descriptionText = props.descriptionText,
      _props$reSendText = props.reSendText,
      reSendText = _props$reSendText === void 0 ? RE_SEND_TEXT : _props$reSendText,
      _props$expiredText = props.expiredText,
      expiredText = _props$expiredText === void 0 ? EXPIRED_OTP : _props$expiredText,
      _props$numInputs = props.numInputs,
      numInputs = _props$numInputs === void 0 ? NUMBER_OF_OTP_INPUT : _props$numInputs,
      _props$countDownTime = props.countDownTime,
      countDownTime = _props$countDownTime === void 0 ? DEFAULT_COUNT_DOWN_TIME : _props$countDownTime,
      isDisabled = props.isDisabled,
      onConfirmOtp = props.onConfirmOtp,
      onResend = props.onResend,
      blockNotifyPopup = props.blockNotifyPopup,
      customizePrefixCls = props.prefixCls,
      className = props.className;

  var _useState = useState(''),
      _useState2 = _slicedToArray(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = useState(false),
      _useState4 = _slicedToArray(_useState3, 2),
      disable = _useState4[0],
      setDisable = _useState4[1];

  var _useState5 = useState(Date.now()),
      _useState6 = _slicedToArray(_useState5, 2),
      otpCountDownTime = _useState6[0],
      setOtpCountDownTime = _useState6[1];

  var _useState7 = useState(),
      _useState8 = _slicedToArray(_useState7, 2),
      error = _useState8[0],
      _setError = _useState8[1];

  var _useState9 = useState(false),
      _useState10 = _slicedToArray(_useState9, 2),
      disabledResend = _useState10[0],
      setDisabledResend = _useState10[1];

  var _React$useContext = React.useContext(ConfigContext),
      getPrefixCls = _React$useContext.getPrefixCls;

  var prefixCls = getPrefixCls('', customizePrefixCls);
  var refOtp = useRef(null);
  var refCountDown = useRef(null); // function for parent component call

  useImperativeHandle(ref, function () {
    return {
      startOtp: function startOtp() {
        var _a;

        (_a = refCountDown.current) === null || _a === void 0 ? void 0 : _a.stopTimer();
        resetOtpCountTime();
        setValue('');

        _setError(null);

        setDisabledResend(true);
        setOtpCountDownTime(Date.now() + countDownTime);
      },
      setBlockTime: function setBlockTime(time) {
        var _a;

        if (time) {
          (_a = refCountDown.current) === null || _a === void 0 ? void 0 : _a.stopTimer();
          setOtpCountBlockTime(time, true);
          setDisable(true);
          setOtpCountDownTime(Date.now() + time);

          if (blockNotifyPopup) {
            blockNotifyPopup();
          }
        }
      },
      setError: function setError(text) {
        _setError(text);
      }
    };
  });

  var handleResendOtp = function handleResendOtp() {
    setValue('');

    _setError(null);

    if (onResend) {
      onResend();
    }
  };

  var handleExpiredOtp = function handleExpiredOtp() {
    if (!isBlockingTime()) {
      _setError(expiredText);
    } else {
      setDisable(false);
      Modal.destroyAll();
    }

    setDisabledResend(false);
    resetOtpCountTime();
  };

  var onCountDownChange = function onCountDownChange(time) {
    setOtpCountTime(time);
  };

  var handleFocus = useCallback(function () {
    var _a;

    return (_a = refOtp.current) === null || _a === void 0 ? void 0 : _a.focusInput(value.length);
  }, [refOtp.current, value]); // handle if has block time

  useEffect(function () {
    var blockTime = getOtpCountTime();

    if (blockTime.isBlock) {
      // calculate block time remind when  otp component destroy and mount again
      var currentTime = new Date().getTime();
      var timeDiffer = currentTime - blockTime.startTime;

      if (timeDiffer < blockTime.time) {
        setDisable(true);
        setOtpCountDownTime(Date.now() + blockTime.time - timeDiffer);

        if (blockNotifyPopup) {
          blockNotifyPopup();
        }
      } else {
        resetOtpCountTime();
      }
    } else {
      setDisable(isDisabled);
    }
  }, [isDisabled]);
  useEffect(function () {
    if (!refOtp.current) return;

    refOtp.current.handleOtpChange = function (val) {
      var _a;

      var otp = val.join('').replace(/\D/g, '');
      setValue(otp);
      (_a = refOtp.current) === null || _a === void 0 ? void 0 : _a.focusInput(otp.length); // khi người dùng nhập lại OTP, xóa error msg

      if (error) _setError(null); // auto validate otp when finish typing

      if (otp.length === numInputs) {
        if (onConfirmOtp) {
          onConfirmOtp(otp);
        }
      }
    };
  }, [refOtp.current, onConfirmOtp]);
  return /*#__PURE__*/React.createElement("div", {
    className: "otp-container ".concat(className || '')
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Typography.Heading, {
    level: 6,
    fontWeight: "semibold",
    className: "space-mb-10"
  }, titleText), /*#__PURE__*/React.createElement(Typography.SubTitle, {
    level: 3
  }, descriptionText)), /*#__PURE__*/React.createElement("div", {
    className: "space-mt-32"
  }, /*#__PURE__*/React.createElement("span", {
    className: classNames(error && 'otp-error', disable && 'otp-disabled'),
    onClick: handleFocus
  }, /*#__PURE__*/React.createElement(ReactOtpInput, _extends({}, props, {
    ref: refOtp,
    value: value,
    containerStyle: "otp-container--wrap-style",
    inputStyle: "otp-container--input-style ".concat(prefixCls, "-input typography-title-2 font-semibold"),
    focusStyle: "otp-container--focus-style",
    numInputs: numInputs,
    isDisabled: disable,
    hasErrored: !!error,
    isInputNum: true,
    shouldAutoFocus: true
  })), error && /*#__PURE__*/React.createElement(Typography.Note, {
    level: 1,
    type: "danger",
    className: "space-mt-8 space-mb-0"
  }, error)), /*#__PURE__*/React.createElement("div", {
    className: "space-mt-8"
  }, /*#__PURE__*/React.createElement(Button, {
    type: "link",
    className: "space-pr-4 typography-caption-1 font-medium btn-resend-otp",
    disabled: disable || disabledResend,
    onClick: handleResendOtp
  }, reSendText), /*#__PURE__*/React.createElement(Countdown, {
    ref: refCountDown,
    className: "otp-container--count-down typography-caption-1 font-medium",
    format: "\xA0(mm:ss)",
    value: otpCountDownTime,
    onFinish: handleExpiredOtp,
    onChange: onCountDownChange
  }))));
};

if (process.env.NODE_ENV !== 'production') {
  OtpComponent.displayName = 'OtpComponent';
}

export default /*#__PURE__*/React.forwardRef(OtpComponent);