import _extends from "@babel/runtime/helpers/esm/extends";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";

var __rest = this && this.__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

import classNames from 'classnames';
import { CautionCircleFilled, CloseCircleFilled, CheckCircleFilled, LeftOutlined, SortOutlined } from "msb-icons-svg/es/src";
import RcSteps from 'rc-steps';
import * as React from 'react';
import AffixFC from '../affix';
import Button from '../button';
import Collapse from '../collapse';
import { ConfigContext } from '../config-provider';
import { Col, Row } from '../grid';
import useBreakpoint from '../grid/hooks/useBreakpoint';
import Progress from '../progress';
import Typography from '../typography';

var Steps = function Steps(props) {
  var _classNames;

  var _a, _b;

  var percent = props.percent,
      size = props.size,
      className = props.className,
      direction = props.direction,
      responsive = props.responsive,
      _props$labelPlacement = props.labelPlacement,
      labelPlacement = _props$labelPlacement === void 0 ? 'vertical' : _props$labelPlacement,
      children = props.children,
      current = props.current,
      isMobile = props.isMobile,
      mobileTop = props.mobileTop,
      onPrevStep = props.onPrevStep,
      onChange = props.onChange,
      restProps = __rest(props, ["percent", "size", "className", "direction", "responsive", "labelPlacement", "children", "current", "isMobile", "mobileTop", "onPrevStep", "onChange"]);

  var _useBreakpoint = useBreakpoint(responsive),
      xs = _useBreakpoint.xs;

  var _React$useContext = React.useContext(ConfigContext),
      getPrefixCls = _React$useContext.getPrefixCls,
      rtlDirection = _React$useContext.direction;

  var _React$useState = React.useState(0),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      mobileShowStep = _React$useState2[0],
      setMobileShowStep = _React$useState2[1];

  var _React$useState3 = React.useState(0),
      _React$useState4 = _slicedToArray(_React$useState3, 2),
      mobileCurrentStep = _React$useState4[0],
      setMobileCurrentStep = _React$useState4[1];

  var _React$useState5 = React.useState(-1),
      _React$useState6 = _slicedToArray(_React$useState5, 2),
      lastStepHasStatus = _React$useState6[0],
      setLastStepHasStatus = _React$useState6[1];

  var getDirection = React.useCallback(function () {
    return responsive && xs ? direction || 'vertical' : direction;
  }, [xs, direction]);
  var prefixCls = getPrefixCls('steps', props.prefixCls);
  var iconPrefix = getPrefixCls('', props.iconPrefix);
  var icons = {
    finish: /*#__PURE__*/React.createElement(CheckCircleFilled, {
      className: "".concat(prefixCls, "-finish-icon")
    }),
    error: /*#__PURE__*/React.createElement(CloseCircleFilled, {
      className: "".concat(prefixCls, "-error-icon")
    }),
    pending: /*#__PURE__*/React.createElement(CautionCircleFilled, {
      style: {
        lineHeight: '20px'
      },
      className: "".concat(prefixCls, "-pending-icon")
    })
  };

  var handleChange = function handleChange(item) {
    if (onChange) {
      onChange(item);
    }
  };

  var mobileToggle = function mobileToggle() {
    setMobileShowStep(mobileShowStep ? 0 : 1);
  };

  var handlePreStep = function handlePreStep(event) {
    event.stopPropagation();

    if (onPrevStep) {
      onPrevStep(current || 0);
    } else if (mobileCurrentStep) {
      setMobileCurrentStep(mobileCurrentStep - 1);
      if (onChange) onChange(mobileCurrentStep);
    }
  };

  var stepIconRender = function stepIconRender(_ref) {
    var node = _ref.node,
        status = _ref.status,
        index = _ref.index;

    if (status !== 'process' && status !== 'wait') {
      setLastStepHasStatus(index);
    }

    if (status === 'process' && percent !== undefined) {
      // currently it's hard-coded, since we can't easily read the actually width of icon
      // MSB override
      var progressWidth = size === 'small' ? 26 : 26; // MSB override

      var iconWithProgress = /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-progress-icon")
      }, /*#__PURE__*/React.createElement(Progress, {
        type: "circle",
        percent: percent,
        width: progressWidth,
        strokeWidth: 4,
        format: function format() {
          return null;
        }
      }), node);
      return iconWithProgress;
    }

    if (status === 'pending') {
      return /*#__PURE__*/React.createElement("span", {
        className: "".concat(prefixCls, "-icon")
      }, /*#__PURE__*/React.createElement(CautionCircleFilled, {
        className: "".concat(prefixCls, "-pending-icon")
      }));
    }

    return node;
  };

  var childStep = React.Children.toArray(children);
  var numSteps = childStep === null || childStep === void 0 ? void 0 : childStep.length;
  var stepsClassName = classNames((_classNames = {}, _defineProperty(_classNames, "".concat(prefixCls, "-rtl"), rtlDirection === 'rtl'), _defineProperty(_classNames, "".concat(prefixCls, "-with-progress"), percent !== undefined), _defineProperty(_classNames, "".concat(prefixCls, "-full-process"), lastStepHasStatus > (current || 0)), _classNames), className);
  React.useEffect(function () {
    setMobileCurrentStep(current || 0);
  }, [current]);
  var steps = /*#__PURE__*/React.createElement(RcSteps, _extends({
    icons: icons
  }, restProps, {
    size: size,
    labelPlacement: labelPlacement,
    direction: getDirection(),
    stepIcon: stepIconRender,
    prefixCls: prefixCls,
    iconPrefix: iconPrefix,
    className: stepsClassName,
    onChange: handleChange,
    current: current
  }), children);
  var mobileHeader = /*#__PURE__*/React.createElement(Row, {
    align: "middle",
    gutter: [8, 4]
  }, /*#__PURE__*/React.createElement(Col, {
    flex: "none "
  }, /*#__PURE__*/React.createElement(Button, {
    type: "text",
    disabled: !mobileCurrentStep,
    shape: "circle",
    onClick: handlePreStep,
    icon: /*#__PURE__*/React.createElement(LeftOutlined, null)
  })), /*#__PURE__*/React.createElement(Col, {
    flex: "auto"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Typography.SubTitle, {
    level: 6,
    fontWeight: "medium",
    className: "space-mb-0"
  }, (_b = (_a = childStep[mobileCurrentStep || 0]) === null || _a === void 0 ? void 0 : _a.props) === null || _b === void 0 ? void 0 : _b.title)), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(Typography.Note, {
    level: 2,
    className: "space-mb-0 ".concat(prefixCls, "-subTitle")
  }, (mobileCurrentStep || 0) + 1, "/", numSteps))), /*#__PURE__*/React.createElement(Col, {
    flex: "none"
  }, /*#__PURE__*/React.createElement(Button, {
    type: "text",
    shape: "circle",
    onClick: mobileToggle,
    icon: /*#__PURE__*/React.createElement(SortOutlined, null)
  })), /*#__PURE__*/React.createElement(Col, {
    span: 24
  }, /*#__PURE__*/React.createElement(Progress, {
    percent: ((mobileCurrentStep || 0) + 1) / numSteps * 100,
    strokeWidth: 4,
    showInfo: false
  })));
  var mobileVer2 = /*#__PURE__*/React.createElement(AffixFC, {
    offsetTop: mobileTop || 0
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-mobile-container ").concat(mobileShowStep)
  }, /*#__PURE__*/React.createElement(Collapse, {
    onChange: mobileToggle,
    activeKey: mobileShowStep
  }, /*#__PURE__*/React.createElement(Collapse.Panel, {
    showArrow: false,
    header: mobileHeader,
    key: "1"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(RcSteps, _extends({
    icons: icons
  }, restProps, {
    size: size,
    labelPlacement: labelPlacement,
    direction: getDirection(),
    stepIcon: stepIconRender,
    prefixCls: prefixCls,
    iconPrefix: iconPrefix,
    className: stepsClassName,
    onChange: handleChange,
    current: mobileCurrentStep
  }), children))))), !!mobileShowStep && /*#__PURE__*/React.createElement("div", {
    className: "ant-modal-mask",
    onClick: function onClick() {
      setMobileShowStep(0);
    }
  })));
  return isMobile ? mobileVer2 : steps;
};

Steps.Step = RcSteps.Step;
Steps.defaultProps = {
  current: 0,
  responsive: true
};
export default Steps;