"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard")["default"];

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = _interopRequireWildcard(require("react"));

var _reactOtpInputRc = _interopRequireDefault(require("react-otp-input-rc-17"));

var _classnames = _interopRequireDefault(require("classnames"));

var _button = _interopRequireDefault(require("../button"));

var _Countdown = _interopRequireDefault(require("../statistic/Countdown"));

var _typography = _interopRequireDefault(require("../typography"));

var _interface = require("./interface");

var _utilities = require("./utilities");

var _configProvider = require("../config-provider");

var _modal = _interopRequireDefault(require("../modal"));

var OtpComponent = function OtpComponent(props, ref) {
  var _props$titleText = props.titleText,
      titleText = _props$titleText === void 0 ? _interface.TITLE_TEXT : _props$titleText,
      descriptionText = props.descriptionText,
      _props$reSendText = props.reSendText,
      reSendText = _props$reSendText === void 0 ? _interface.RE_SEND_TEXT : _props$reSendText,
      _props$expiredText = props.expiredText,
      expiredText = _props$expiredText === void 0 ? _interface.EXPIRED_OTP : _props$expiredText,
      _props$numInputs = props.numInputs,
      numInputs = _props$numInputs === void 0 ? _interface.NUMBER_OF_OTP_INPUT : _props$numInputs,
      _props$countDownTime = props.countDownTime,
      countDownTime = _props$countDownTime === void 0 ? _interface.DEFAULT_COUNT_DOWN_TIME : _props$countDownTime,
      isDisabled = props.isDisabled,
      onConfirmOtp = props.onConfirmOtp,
      onResend = props.onResend,
      blockNotifyPopup = props.blockNotifyPopup,
      customizePrefixCls = props.prefixCls,
      className = props.className;

  var _useState = (0, _react.useState)(''),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      value = _useState2[0],
      setValue = _useState2[1];

  var _useState3 = (0, _react.useState)(false),
      _useState4 = (0, _slicedToArray2["default"])(_useState3, 2),
      disable = _useState4[0],
      setDisable = _useState4[1];

  var _useState5 = (0, _react.useState)(Date.now()),
      _useState6 = (0, _slicedToArray2["default"])(_useState5, 2),
      otpCountDownTime = _useState6[0],
      setOtpCountDownTime = _useState6[1];

  var _useState7 = (0, _react.useState)(),
      _useState8 = (0, _slicedToArray2["default"])(_useState7, 2),
      error = _useState8[0],
      _setError = _useState8[1];

  var _useState9 = (0, _react.useState)(false),
      _useState10 = (0, _slicedToArray2["default"])(_useState9, 2),
      disabledResend = _useState10[0],
      setDisabledResend = _useState10[1];

  var _React$useContext = _react["default"].useContext(_configProvider.ConfigContext),
      getPrefixCls = _React$useContext.getPrefixCls;

  var prefixCls = getPrefixCls('', customizePrefixCls);
  var refOtp = (0, _react.useRef)(null);
  var refCountDown = (0, _react.useRef)(null); // function for parent component call

  (0, _react.useImperativeHandle)(ref, function () {
    return {
      startOtp: function startOtp() {
        var _a;

        (_a = refCountDown.current) === null || _a === void 0 ? void 0 : _a.stopTimer();
        (0, _utilities.resetOtpCountTime)();
        setValue('');

        _setError(null);

        setDisabledResend(true);
        setOtpCountDownTime(Date.now() + countDownTime);
      },
      setBlockTime: function setBlockTime(time) {
        var _a;

        if (time) {
          (_a = refCountDown.current) === null || _a === void 0 ? void 0 : _a.stopTimer();
          (0, _utilities.setOtpCountBlockTime)(time, true);
          setDisable(true);
          setOtpCountDownTime(Date.now() + time);

          if (blockNotifyPopup) {
            blockNotifyPopup();
          }
        }
      },
      setError: function setError(text) {
        _setError(text);
      }
    };
  });

  var handleResendOtp = function handleResendOtp() {
    setValue('');

    _setError(null);

    if (onResend) {
      onResend();
    }
  };

  var handleExpiredOtp = function handleExpiredOtp() {
    if (!(0, _utilities.isBlockingTime)()) {
      _setError(expiredText);
    } else {
      setDisable(false);

      _modal["default"].destroyAll();
    }

    setDisabledResend(false);
    (0, _utilities.resetOtpCountTime)();
  };

  var onCountDownChange = function onCountDownChange(time) {
    (0, _utilities.setOtpCountTime)(time);
  };

  var handleFocus = (0, _react.useCallback)(function () {
    var _a;

    return (_a = refOtp.current) === null || _a === void 0 ? void 0 : _a.focusInput(value.length);
  }, [refOtp.current, value]); // handle if has block time

  (0, _react.useEffect)(function () {
    var blockTime = (0, _utilities.getOtpCountTime)();

    if (blockTime.isBlock) {
      // calculate block time remind when  otp component destroy and mount again
      var currentTime = new Date().getTime();
      var timeDiffer = currentTime - blockTime.startTime;

      if (timeDiffer < blockTime.time) {
        setDisable(true);
        setOtpCountDownTime(Date.now() + blockTime.time - timeDiffer);

        if (blockNotifyPopup) {
          blockNotifyPopup();
        }
      } else {
        (0, _utilities.resetOtpCountTime)();
      }
    } else {
      setDisable(isDisabled);
    }
  }, [isDisabled]);
  (0, _react.useEffect)(function () {
    if (!refOtp.current) return;

    refOtp.current.handleOtpChange = function (val) {
      var _a;

      var otp = val.join('').replace(/\D/g, '');
      setValue(otp);
      (_a = refOtp.current) === null || _a === void 0 ? void 0 : _a.focusInput(otp.length); // khi người dùng nhập lại OTP, xóa error msg

      if (error) _setError(null); // auto validate otp when finish typing

      if (otp.length === numInputs) {
        if (onConfirmOtp) {
          onConfirmOtp(otp);
        }
      }
    };
  }, [refOtp.current, onConfirmOtp]);
  return /*#__PURE__*/_react["default"].createElement("div", {
    className: "otp-container ".concat(className || '')
  }, /*#__PURE__*/_react["default"].createElement("div", null, /*#__PURE__*/_react["default"].createElement(_typography["default"].Heading, {
    level: 6,
    fontWeight: "semibold",
    className: "space-mb-10"
  }, titleText), /*#__PURE__*/_react["default"].createElement(_typography["default"].SubTitle, {
    level: 3
  }, descriptionText)), /*#__PURE__*/_react["default"].createElement("div", {
    className: "space-mt-32"
  }, /*#__PURE__*/_react["default"].createElement("span", {
    className: (0, _classnames["default"])(error && 'otp-error', disable && 'otp-disabled'),
    onClick: handleFocus
  }, /*#__PURE__*/_react["default"].createElement(_reactOtpInputRc["default"], (0, _extends2["default"])({}, props, {
    ref: refOtp,
    value: value,
    containerStyle: "otp-container--wrap-style",
    inputStyle: "otp-container--input-style ".concat(prefixCls, "-input typography-title-2 font-semibold"),
    focusStyle: "otp-container--focus-style",
    numInputs: numInputs,
    isDisabled: disable,
    hasErrored: !!error,
    isInputNum: true,
    shouldAutoFocus: true
  })), error && /*#__PURE__*/_react["default"].createElement(_typography["default"].Note, {
    level: 1,
    type: "danger",
    className: "space-mt-8 space-mb-0"
  }, error)), /*#__PURE__*/_react["default"].createElement("div", {
    className: "space-mt-8"
  }, /*#__PURE__*/_react["default"].createElement(_button["default"], {
    type: "link",
    className: "space-pr-4 typography-caption-1 font-medium btn-resend-otp",
    disabled: disable || disabledResend,
    onClick: handleResendOtp
  }, reSendText), /*#__PURE__*/_react["default"].createElement(_Countdown["default"], {
    ref: refCountDown,
    className: "otp-container--count-down typography-caption-1 font-medium",
    format: "\xA0(mm:ss)",
    value: otpCountDownTime,
    onFinish: handleExpiredOtp,
    onChange: onCountDownChange
  }))));
};

if (process.env.NODE_ENV !== 'production') {
  OtpComponent.displayName = 'OtpComponent';
}

var _default = /*#__PURE__*/_react["default"].forwardRef(OtpComponent);

exports["default"] = _default;