"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setOtpCountTime = exports.setOtpCountBlockTime = exports.resetOtpCountTime = exports.isBlockingTime = exports.getOtpCountTimeOrigin = exports.getOtpCountTime = exports.clearOtpCountTime = void 0;
var OTP_BLOCKING_TIME = 'OTP_BLOCKING_TIME';

var clearOtpCountTime = function clearOtpCountTime() {
  localStorage.removeItem(OTP_BLOCKING_TIME);
};

exports.clearOtpCountTime = clearOtpCountTime;

var setOtpCountBlockTime = function setOtpCountBlockTime(time, isBlock) {
  if (time) {
    var obj = {
      startTime: new Date().getTime(),
      time: time,
      isBlock: isBlock
    };
    localStorage.setItem(OTP_BLOCKING_TIME, JSON.stringify(obj));
  } else {
    clearOtpCountTime();
  }
};

exports.setOtpCountBlockTime = setOtpCountBlockTime;

var getOtpCountTimeOrigin = function getOtpCountTimeOrigin() {
  var otpTime = localStorage.getItem(OTP_BLOCKING_TIME);

  if (otpTime) {
    return JSON.parse(otpTime);
  }

  return null;
};

exports.getOtpCountTimeOrigin = getOtpCountTimeOrigin;

var setOtpCountTime = function setOtpCountTime(time) {
  var currentObj = getOtpCountTimeOrigin();
  var obj;

  if (time) {
    obj = {
      startTime: (currentObj === null || currentObj === void 0 ? void 0 : currentObj.startTime) || new Date().getTime(),
      time: time || 0,
      isBlock: currentObj === null || currentObj === void 0 ? void 0 : currentObj.isBlock
    };
  } else {
    obj = {
      startTime: new Date().getTime(),
      time: 0,
      isBlock: false
    };
  }

  localStorage.setItem(OTP_BLOCKING_TIME, JSON.stringify(obj));
};

exports.setOtpCountTime = setOtpCountTime;

var resetOtpCountTime = function resetOtpCountTime() {
  setOtpCountTime(0);
};

exports.resetOtpCountTime = resetOtpCountTime;

var getOtpCountTime = function getOtpCountTime() {
  var otpTime = localStorage.getItem(OTP_BLOCKING_TIME);

  if (otpTime) {
    var objOtpTime = JSON.parse(otpTime);
    return objOtpTime;
  }

  return {
    startTime: new Date().getTime(),
    time: 0,
    isBlock: false
  };
};

exports.getOtpCountTime = getOtpCountTime;

var isBlockingTime = function isBlockingTime() {
  var currentTime = localStorage.getItem(OTP_BLOCKING_TIME);

  if (currentTime) {
    var objOtpTime = JSON.parse(currentTime);
    return objOtpTime.isBlock;
  }

  return false;
};

exports.isBlockingTime = isBlockingTime;