"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard")["default"];

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _classnames = _interopRequireDefault(require("classnames"));

var _src = require("msb-icons-svg/lib/src");

var _rcSteps = _interopRequireDefault(require("rc-steps"));

var React = _interopRequireWildcard(require("react"));

var _affix = _interopRequireDefault(require("../affix"));

var _button = _interopRequireDefault(require("../button"));

var _collapse = _interopRequireDefault(require("../collapse"));

var _configProvider = require("../config-provider");

var _grid = require("../grid");

var _useBreakpoint2 = _interopRequireDefault(require("../grid/hooks/useBreakpoint"));

var _progress = _interopRequireDefault(require("../progress"));

var _typography = _interopRequireDefault(require("../typography"));

var __rest = void 0 && (void 0).__rest || function (s, e) {
  var t = {};

  for (var p in s) {
    if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0) t[p] = s[p];
  }

  if (s != null && typeof Object.getOwnPropertySymbols === "function") for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
    if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i])) t[p[i]] = s[p[i]];
  }
  return t;
};

var Steps = function Steps(props) {
  var _classNames;

  var _a, _b;

  var percent = props.percent,
      size = props.size,
      className = props.className,
      direction = props.direction,
      responsive = props.responsive,
      _props$labelPlacement = props.labelPlacement,
      labelPlacement = _props$labelPlacement === void 0 ? 'vertical' : _props$labelPlacement,
      children = props.children,
      current = props.current,
      isMobile = props.isMobile,
      mobileTop = props.mobileTop,
      onPrevStep = props.onPrevStep,
      onChange = props.onChange,
      restProps = __rest(props, ["percent", "size", "className", "direction", "responsive", "labelPlacement", "children", "current", "isMobile", "mobileTop", "onPrevStep", "onChange"]);

  var _useBreakpoint = (0, _useBreakpoint2["default"])(responsive),
      xs = _useBreakpoint.xs;

  var _React$useContext = React.useContext(_configProvider.ConfigContext),
      getPrefixCls = _React$useContext.getPrefixCls,
      rtlDirection = _React$useContext.direction;

  var _React$useState = React.useState(0),
      _React$useState2 = (0, _slicedToArray2["default"])(_React$useState, 2),
      mobileShowStep = _React$useState2[0],
      setMobileShowStep = _React$useState2[1];

  var _React$useState3 = React.useState(0),
      _React$useState4 = (0, _slicedToArray2["default"])(_React$useState3, 2),
      mobileCurrentStep = _React$useState4[0],
      setMobileCurrentStep = _React$useState4[1];

  var _React$useState5 = React.useState(-1),
      _React$useState6 = (0, _slicedToArray2["default"])(_React$useState5, 2),
      lastStepHasStatus = _React$useState6[0],
      setLastStepHasStatus = _React$useState6[1];

  var getDirection = React.useCallback(function () {
    return responsive && xs ? direction || 'vertical' : direction;
  }, [xs, direction]);
  var prefixCls = getPrefixCls('steps', props.prefixCls);
  var iconPrefix = getPrefixCls('', props.iconPrefix);
  var icons = {
    finish: /*#__PURE__*/React.createElement(_src.CheckCircleFilled, {
      className: "".concat(prefixCls, "-finish-icon")
    }),
    error: /*#__PURE__*/React.createElement(_src.CloseCircleFilled, {
      className: "".concat(prefixCls, "-error-icon")
    }),
    pending: /*#__PURE__*/React.createElement(_src.CautionCircleFilled, {
      style: {
        lineHeight: '20px'
      },
      className: "".concat(prefixCls, "-pending-icon")
    })
  };

  var handleChange = function handleChange(item) {
    if (onChange) {
      onChange(item);
    }
  };

  var mobileToggle = function mobileToggle() {
    setMobileShowStep(mobileShowStep ? 0 : 1);
  };

  var handlePreStep = function handlePreStep(event) {
    event.stopPropagation();

    if (onPrevStep) {
      onPrevStep(current || 0);
    } else if (mobileCurrentStep) {
      setMobileCurrentStep(mobileCurrentStep - 1);
      if (onChange) onChange(mobileCurrentStep);
    }
  };

  var stepIconRender = function stepIconRender(_ref) {
    var node = _ref.node,
        status = _ref.status,
        index = _ref.index;

    if (status !== 'process' && status !== 'wait') {
      setLastStepHasStatus(index);
    }

    if (status === 'process' && percent !== undefined) {
      // currently it's hard-coded, since we can't easily read the actually width of icon
      // MSB override
      var progressWidth = size === 'small' ? 26 : 26; // MSB override

      var iconWithProgress = /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-progress-icon")
      }, /*#__PURE__*/React.createElement(_progress["default"], {
        type: "circle",
        percent: percent,
        width: progressWidth,
        strokeWidth: 4,
        format: function format() {
          return null;
        }
      }), node);
      return iconWithProgress;
    }

    if (status === 'pending') {
      return /*#__PURE__*/React.createElement("span", {
        className: "".concat(prefixCls, "-icon")
      }, /*#__PURE__*/React.createElement(_src.CautionCircleFilled, {
        className: "".concat(prefixCls, "-pending-icon")
      }));
    }

    return node;
  };

  var childStep = React.Children.toArray(children);
  var numSteps = childStep === null || childStep === void 0 ? void 0 : childStep.length;
  var stepsClassName = (0, _classnames["default"])((_classNames = {}, (0, _defineProperty2["default"])(_classNames, "".concat(prefixCls, "-rtl"), rtlDirection === 'rtl'), (0, _defineProperty2["default"])(_classNames, "".concat(prefixCls, "-with-progress"), percent !== undefined), (0, _defineProperty2["default"])(_classNames, "".concat(prefixCls, "-full-process"), lastStepHasStatus > (current || 0)), _classNames), className);
  React.useEffect(function () {
    setMobileCurrentStep(current || 0);
  }, [current]);
  var steps = /*#__PURE__*/React.createElement(_rcSteps["default"], (0, _extends2["default"])({
    icons: icons
  }, restProps, {
    size: size,
    labelPlacement: labelPlacement,
    direction: getDirection(),
    stepIcon: stepIconRender,
    prefixCls: prefixCls,
    iconPrefix: iconPrefix,
    className: stepsClassName,
    onChange: handleChange,
    current: current
  }), children);
  var mobileHeader = /*#__PURE__*/React.createElement(_grid.Row, {
    align: "middle",
    gutter: [8, 4]
  }, /*#__PURE__*/React.createElement(_grid.Col, {
    flex: "none "
  }, /*#__PURE__*/React.createElement(_button["default"], {
    type: "text",
    disabled: !mobileCurrentStep,
    shape: "circle",
    onClick: handlePreStep,
    icon: /*#__PURE__*/React.createElement(_src.LeftOutlined, null)
  })), /*#__PURE__*/React.createElement(_grid.Col, {
    flex: "auto"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(_typography["default"].SubTitle, {
    level: 6,
    fontWeight: "medium",
    className: "space-mb-0"
  }, (_b = (_a = childStep[mobileCurrentStep || 0]) === null || _a === void 0 ? void 0 : _a.props) === null || _b === void 0 ? void 0 : _b.title)), /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(_typography["default"].Note, {
    level: 2,
    className: "space-mb-0 ".concat(prefixCls, "-subTitle")
  }, (mobileCurrentStep || 0) + 1, "/", numSteps))), /*#__PURE__*/React.createElement(_grid.Col, {
    flex: "none"
  }, /*#__PURE__*/React.createElement(_button["default"], {
    type: "text",
    shape: "circle",
    onClick: mobileToggle,
    icon: /*#__PURE__*/React.createElement(_src.SortOutlined, null)
  })), /*#__PURE__*/React.createElement(_grid.Col, {
    span: 24
  }, /*#__PURE__*/React.createElement(_progress["default"], {
    percent: ((mobileCurrentStep || 0) + 1) / numSteps * 100,
    strokeWidth: 4,
    showInfo: false
  })));
  var mobileVer2 = /*#__PURE__*/React.createElement(_affix["default"], {
    offsetTop: mobileTop || 0
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement("div", {
    className: "".concat(prefixCls, "-mobile-container ").concat(mobileShowStep)
  }, /*#__PURE__*/React.createElement(_collapse["default"], {
    onChange: mobileToggle,
    activeKey: mobileShowStep
  }, /*#__PURE__*/React.createElement(_collapse["default"].Panel, {
    showArrow: false,
    header: mobileHeader,
    key: "1"
  }, /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(_rcSteps["default"], (0, _extends2["default"])({
    icons: icons
  }, restProps, {
    size: size,
    labelPlacement: labelPlacement,
    direction: getDirection(),
    stepIcon: stepIconRender,
    prefixCls: prefixCls,
    iconPrefix: iconPrefix,
    className: stepsClassName,
    onChange: handleChange,
    current: mobileCurrentStep
  }), children))))), !!mobileShowStep && /*#__PURE__*/React.createElement("div", {
    className: "ant-modal-mask",
    onClick: function onClick() {
      setMobileShowStep(0);
    }
  })));
  return isMobile ? mobileVer2 : steps;
};

Steps.Step = _rcSteps["default"].Step;
Steps.defaultProps = {
  current: 0,
  responsive: true
};
var _default = Steps;
exports["default"] = _default;