"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault")["default"];

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.file2Obj = file2Obj;
exports.getFileItem = getFileItem;
exports.isImageUrl = exports.getIconByFileType = void 0;
exports.previewImage = previewImage;
exports.removeFileItem = removeFileItem;
exports.updateFileList = updateFileList;

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _other = require("msb-icons-svg/lib/src/other");

var _react = _interopRequireDefault(require("react"));

var _interface = require("./interface");

function file2Obj(file) {
  return (0, _extends2["default"])((0, _extends2["default"])({}, file), {
    lastModified: file.lastModified,
    lastModifiedDate: file.lastModifiedDate,
    name: file.name,
    size: file.size,
    type: file.type,
    uid: file.uid,
    percent: 0,
    originFileObj: file
  });
}
/** Upload fileList. Replace file if exist or just push into it. */


function updateFileList(file, fileList) {
  var nextFileList = (0, _toConsumableArray2["default"])(fileList);
  var fileIndex = nextFileList.findIndex(function (_ref) {
    var uid = _ref.uid;
    return uid === file.uid;
  });

  if (fileIndex === -1) {
    nextFileList.push(file);
  } else {
    nextFileList[fileIndex] = file;
  }

  return nextFileList;
}

function getFileItem(file, fileList) {
  var matchKey = file.uid !== undefined ? 'uid' : 'name';
  return fileList.filter(function (item) {
    return item[matchKey] === file[matchKey];
  })[0];
}

function removeFileItem(file, fileList) {
  var matchKey = file.uid !== undefined ? 'uid' : 'name';
  var removed = fileList.filter(function (item) {
    return item[matchKey] !== file[matchKey];
  });

  if (removed.length === fileList.length) {
    return null;
  }

  return removed;
} // ==================== Default Image Preview ====================


var extname = function extname() {
  var url = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : '';
  var temp = url.split('/');
  var filename = temp[temp.length - 1];
  var filenameWithoutSuffix = filename.split(/#|\?/)[0];
  return (/\.[^./\\]*$/.exec(filenameWithoutSuffix) || [''])[0];
};

var isImageFileType = function isImageFileType(type) {
  return type.indexOf('image/') === 0;
};

var isImageUrl = function isImageUrl(file) {
  if (file.type && !file.thumbUrl) {
    return isImageFileType(file.type);
  }

  var url = file.thumbUrl || file.url || '';
  var extension = extname(url);

  if (/^data:image\//.test(url) || /(webp|svg|png|gif|jpg|jpeg|jfif|bmp|dpg|ico)$/i.test(extension)) {
    return true;
  }

  if (/^data:/.test(url)) {
    // other file types of base64
    return false;
  }

  if (extension) {
    // other file types which have extension
    return false;
  }

  return true;
};

exports.isImageUrl = isImageUrl;

var getTypeFileByName = function getTypeFileByName(fileName) {
  var fileExtensionsPatterns = [{
    type: _interface.PreviewFileType.PDF,
    pattern: _interface.PatternValidate.pdfExtensionPattern
  }, {
    type: _interface.PreviewFileType.XML,
    pattern: _interface.PatternValidate.xmlExtensionPattern
  }, {
    type: _interface.PreviewFileType.IMAGE,
    pattern: _interface.PatternValidate.imageExtensionPattern
  }, {
    type: _interface.PreviewFileType.WORD,
    pattern: _interface.PatternValidate.wordExtensionPattern
  }, {
    type: _interface.PreviewFileType.EXCEL,
    pattern: _interface.PatternValidate.excelsExtensionPattern
  }];
  var fileType = _interface.PreviewFileType.OTHER;

  for (var index = 0; index < fileExtensionsPatterns.length; index++) {
    var pattern = fileExtensionsPatterns[index];

    if (fileName.match(pattern.pattern)) {
      fileType = pattern.type;
      break;
    }
  }

  return fileType;
};

var getIconByFileType = function getIconByFileType(fileName) {
  var fileType = getTypeFileByName(fileName);

  switch (fileType) {
    case _interface.PreviewFileType.EXCEL:
      return /*#__PURE__*/_react["default"].createElement(_other.FileXLSXIcon, null);

    case _interface.PreviewFileType.WORD:
      return /*#__PURE__*/_react["default"].createElement(_other.FileDocIcon, null);

    case _interface.PreviewFileType.PDF:
      return /*#__PURE__*/_react["default"].createElement(_other.FilePdfIcon, null);

    case _interface.PreviewFileType.XML:
      return /*#__PURE__*/_react["default"].createElement(_other.FileXmlIcon, null);

    case _interface.PreviewFileType.IMAGE:
      return /*#__PURE__*/_react["default"].createElement(_other.FileImgIcon, null);

    default:
      return /*#__PURE__*/_react["default"].createElement(_other.FileUnknownIcon, null);
  }
};

exports.getIconByFileType = getIconByFileType;
var MEASURE_SIZE = 200;

function previewImage(file) {
  return new Promise(function (resolve) {
    if (!file.type || !isImageFileType(file.type)) {
      resolve('');
      return;
    }

    var canvas = document.createElement('canvas');
    canvas.width = MEASURE_SIZE;
    canvas.height = MEASURE_SIZE;
    canvas.style.cssText = "position: fixed; left: 0; top: 0; width: ".concat(MEASURE_SIZE, "px; height: ").concat(MEASURE_SIZE, "px; z-index: 9999; display: none;");
    document.body.appendChild(canvas);
    var ctx = canvas.getContext('2d');
    var img = new Image();

    img.onload = function () {
      var width = img.width,
          height = img.height;
      var drawWidth = MEASURE_SIZE;
      var drawHeight = MEASURE_SIZE;
      var offsetX = 0;
      var offsetY = 0;

      if (width > height) {
        drawHeight = height * (MEASURE_SIZE / width);
        offsetY = -(drawHeight - drawWidth) / 2;
      } else {
        drawWidth = width * (MEASURE_SIZE / height);
        offsetX = -(drawWidth - drawHeight) / 2;
      }

      ctx.drawImage(img, offsetX, offsetY, drawWidth, drawHeight);
      var dataURL = canvas.toDataURL();
      document.body.removeChild(canvas);
      resolve(dataURL);
    };

    img.crossOrigin = 'anonymous';

    if (file.type.startsWith('image/svg+xml')) {
      var reader = new FileReader();
      reader.addEventListener('load', function () {
        if (reader.result) img.src = reader.result;
      });
      reader.readAsDataURL(file);
    } else {
      img.src = window.URL.createObjectURL(file);
    }
  });
}